* Program creating plots

/*Program for plotting results (etbgraph)

Parameters (optional parameters in brackets)
	- namelist: list of variables to be plotted. If more varaibles used at a time, all the plots will have the same
	independent variable. Also, if specific titles or labels are used, all the plots will get the same ones (so in this
	case, it is not useful to call the program wih more variables at a time).
	-[if]: optional if expression allowed
Options
	- [xvar(string)]: name of independent variable. If not specified, it will be ginc (gross income).
	- [mode(string)]: 3 possibilities: scatter, kdensity, lpoly (equiv. to Stata commands). Default option: scatter
	- [xlb(int)]: lower bound for independent (x) variable (default 10,000)
	- [xub(int)]: upper bound for independent (x) variable (default 2,000,000)
	- [ylb(int)]: lower bound for dependent (y) variable (default -10,000,000)
	- [yub(int)]: upper bound for dependent (y) variable (default 10,000,000)
	- [title(string)]: title of the plot (by default, the name of the dependent variable)
	- [subtitle(string)]: subtitle of the plot
	- [label(string)]: label of the plot (the same use as with twoway command)
	
Examples:
1) Using all the available options/parameters
	etbgraph totaltax0 if vek>0, xvar(ginc_i) xlb(10000) xub(2000000) ylb(5000) yub(150000) title("TITLE") subtitle("SUBTITLE") label("LABEL")
2) The minimum syntax example
	etbgraph inctax0
3) Example of plotting more variables at a time
	etbgraph inctax0 netinc0
*/
capture program drop etbgraph
program define etbgraph
syntax namelist [if/], [xvar(string) mode(string) xlb(int 7999) xub(int 2000000) ylb(int -10000000) yub(int 10000000) title(string) subtitle(string) label(string)]

*capture mkdir SILC_plots/`t' //all graphs generated by this program are saved in folder SILC_plots (filename = `var')

//Checking whether independent variable (xvar) is specified. If not, take it to be ginc_i.
if "`xvar'"==""{
local xvar "ginc_i" //default option for independent variable
}


//If there is an if condition, put "&" at the beginning of the macro.
//This is just an easy way of handling both the case when if condition is given and when it is not.
//Needed because we already have some if conditions specified for plotting (bounds).
if "`if'"!=""{
local if "& `if'"
}

if "`mode'"==""{ //default mode: scatter plot
local mode "scatter"
}

if "`title'"==""{
local titlenotdefined 1
//necessary in the case of plotting multiple variables at a time when title not specified (otherwise
//all plots would have the same title - name of the first variable)
}
if "`subtitle'"==""{
local subtitlenotdefined 1
}

foreach var of local namelist{
//If no title given, it is taken to be the name of the dependent variable
if "`titlenotdefined'"~=""{
local title "`var'"
}

//plotting - one of 3 possibilities: scatter plot, kdensity, or lpoly
if "`mode'"=="scatter"{ 
twoway (scatter `var' `xvar' if `xvar' > `xlb' & `xvar' < `xub' & `var'>`ylb' & `var'<`yub' `if' ///
, legend(label(1 "`label'"))), saving(`var', replace) title("`title'") sub("`subtitle'") nodraw
}

if "`mode'"=="lpoly_scatter"{
//1) Weighted by pkoef (peerson=weighted)
if "`subtitlenotdefined'"~=""{
local subtitle "weighted by persons"
}
lpoly `var' `xvar' if `xvar' > `xlb' & `xvar' < `xub' & `var'>`ylb' & `var'<`yub' `if' [fw=round(pkoef)] ///
,bw(5000) title("`title'") sub("`subtitle'") saving("`var'", replace) nodraw
}

if "`mode'"=="lpoly"{
//1) Weighted by pkoef (peerson=weighted)
if "`subtitlenotdefined'"~=""{
local subtitle "weighted by persons"
}
lpoly `var' `xvar' if `xvar' > `xlb' & `xvar' < `xub' & `var'>`ylb' & `var'<`yub' `if' [fw=round(pkoef)] ///
,noscatter bw(5000) title("`title'") sub("`subtitle'") saving("lpoly`var'", replace) nodraw

//2) Weighted by pkoef*xvariable (by default: pkoef*ginc_i) (income-weighted)
if "`subtitlenotdefined'"~=""{
local subtitle "weighted by income"
}
lpoly `var' `xvar' if `xvar' > `xlb' & `xvar' < `xub' & `var'>`ylb' & `var'<`yub' `if' [fw=round(pkoef*`xvar')] ///
,noscatter bw(5000) title("`title'") sub("`subtitle'") saving("lpoly`var'incomeweight", replace) nodraw
}

//kdensity -> in this case, xvar used only for bounds! Again, plot both person-weighted and income-weighted.

if "`mode'"=="kdensity"{
//1) Weighted by pkoef (peerson=weighted)
if "`subtitlenotdefined'"~=""{
local subtitle "weighted by persons"
}
kdensity `var' if `xvar' > `xlb' & `xvar' < `xub' `if' [fw=round(pkoef)] ///
,title("`title'") sub("`subtitle'") saving("kdensity`var'", replace) nodraw

//2) Weighted by pkoef*xvariable (by default: pkoef*ginc_i) (income-weighted)
if "`subtitlenotdefined'"~=""{
local subtitle "weighted by income"
}
kdensity `var' if `xvar' > `xlb' & `xvar' < `xub' `if' [fw=round(pkoef*`xvar')] ///
,title("`title'") sub("`subtitle'") saving("kdensity`var'incomeweight", replace) nodraw
}

}

end

* Executing the plots
capture program drop taxbenplots
program define taxbenplots
args t 
	set more off
	cd output_`t'
	use taxbenchars_`t', clear
	capture mkdir plots_`t'
	cd plots_`t'
	
	***plots of ATR's***	
	etbgraph pATR_w_`t', xvar("ginc_w") mode(lpoly_scatter) title("Average Tax Rate, work income, `t'") subtitle("All income and payroll taxes")
	etbgraph pATR_b_`t', xvar("ginc_b") mode(lpoly_scatter) title("Average Tax Rate, business income, `t'") subtitle("All income and payroll taxes")
	etbgraph pATR_i_`t', xvar("ginc_i") mode(lpoly_scatter) title("Average Tax Rate, all income, `t'") subtitle("All income and payroll taxes")
	
	*** HH-level: plots of household level ATRs (including benefits)***
	** these graphs do not say much...
	etbgraph phhATR_ben_`t' if vztah==1 & hhnonpen==1 , xvar("hhginc_perunit") mode(lpoly_scatter) title("HH-level average benefit rate on all income, `t'") subtitle("Households with positive income only")
	etbgraph phhATR_tax_`t' if vztah==1 & hhnonpen==1 , xvar("hhginc_perunit") mode(lpoly_scatter) title("HH-level average tax rate on all income, `t'") subtitle("Households with positive income only")
	etbgraph phhATR_all_`t' if vztah==1 & hhnonpen==1 , xvar("hhginc_perunit") mode(lpoly_scatter) title("HH-level average net tax rate on all income, `t'") subtitle("Households with positive income only")

	***plots of total tax as a fn of income***
	etbgraph totaltax_w_`t', xvar("ginc_w") mode(lpoly_scatter) title("Total tax on work income, `t'") subtitle("All income and payroll taxes") 
	etbgraph totaltax_b_`t', xvar("ginc_b") mode(lpoly_scatter) title("Total tax on business income, `t'") subtitle("All income and payroll taxes") 
	etbgraph totaltax_i_`t', xvar("ginc_i") mode(lpoly_scatter) title("Total tax on all income, `t'") subtitle("All income and payroll taxes") 

	*** HH-level: plots of total taxes and benefits as a fn of income***
	etbgraph hhtotaltax_perunit_`t' if vztah==1 & hhnonpen==1, xvar("hhginc_perunit") mode(lpoly_scatter) title("Total household taxes per OECD unit, `t'") subtitle("All households")
 	etbgraph hhtotalben_perunit_`t' if vztah==1 & hhnonpen==1, xvar("hhginc_perunit") mode(lpoly_scatter) title("Total household benefits per OECD unit, `t'") subtitle("All households") 
	etbgraph hhnettax_perunit_`t' if vztah==1 & hhnonpen==1, xvar("hhginc_perunit") mode(lpoly_scatter) title("Total household net taxes per OECD unit, `t'") subtitle("All households") 

	*** HH-level: plot of net income (after taxes and benefits) as a fn of income
	etbgraph hhnetinc_perunit_`t' if vztah==1 & hhnonpen==1, xvar("hhnetinc_perunit") mode(lpoly_scatter) title("Total household net income per OECD unit, `t'") subtitle("All households")
 	
	*** plot of kernel density of income ***
	etbgraph ginc_w , xvar("ginc_w") mode(kdensity) title("Kernel density of gross work income")
	etbgraph ginc_b , xvar("ginc_b") mode(kdensity) title("Kernel density of gross business income")
	etbgraph ginc_i , xvar("ginc_i") mode(kdensity) title("Kernel density of gross income (work+business)")
	
	*** plots of MTR's - tax only
	etbgraph pmtr_tax_w_`t', xvar("ginc_w") mode(lpoly_scatter) title("Marginal Tax Rate, work income, `t'") subtitle("All income and payroll taxes")
	etbgraph pmtr_tax_b_`t', xvar("ginc_b") mode(lpoly_scatter) title("Marginal Tax Rate, business income, `t'") subtitle("All income and payroll taxes")
	etbgraph pmtr_tax_i_`t', xvar("ginc_i")  mode(lpoly_scatter) title("Marginal Tax Rate, all income, `t'") subtitle("All income and payroll taxes")

	*** plots of MTR's - full 
	etbgraph pmtr_all_w_`t', xvar("ginc_w") mode(lpoly_scatter) title("Effective Marginal Tax Rate, work income, `t'") subtitle("All income and payroll taxes")
	etbgraph pmtr_all_b_`t', xvar("ginc_b") mode(lpoly_scatter) title("Effective Marginal Tax Rate, business income, `t'") subtitle("All income and payroll taxes")
	etbgraph pmtr_all_i_`t', xvar("ginc_i")  mode(lpoly_scatter) title("Effective Marginal Tax Rate, all income, `t'") subtitle("All income and payroll taxes")

	*** plots of PTR's - tax only
	etbgraph pptr_tax_w_`t', xvar("ginc_w") mode(lpoly_scatter) title("Participation Tax Rate, work income, `t'") subtitle("Income tax and payroll taxes")
	etbgraph pptr_tax_b_`t', xvar("ginc_b") mode(lpoly_scatter) title("Participation Tax Rate, business income, `t'") subtitle("Income tax and payroll taxes")
	etbgraph pptr_tax_i_`t', xvar("ginc_i")  mode(lpoly_scatter) title("Participation Tax Rate, all income, `t'") subtitle("Income tax and payroll taxes")
	
	*** plots of PTR's - ben only
	etbgraph pptr_ben_w_`t', xvar("ginc_w") mode(lpoly_scatter) title("Benefit Withdrawal Rate, work income, `t'") subtitle("Welfare benefits")
	etbgraph pptr_ben_b_`t', xvar("ginc_b") mode(lpoly_scatter) title("Benefit Withdrawal Rate, business income, `t'") subtitle("Welfare benefits")
	etbgraph pptr_ben_i_`t', xvar("ginc_i")  mode(lpoly_scatter) title("Benefit Withdrawal Rate, all income, `t'") subtitle("Welfare benefits")

	*** plots of PTR's - full 
	etbgraph pptr_all_w_`t', xvar("ginc_w") mode(lpoly_scatter) title("Effective Participation Tax Rate, work income, `t'") subtitle("Income tax, payroll taxes, and welfare benefits")
	etbgraph pptr_all_b_`t', xvar("ginc_b") mode(lpoly_scatter) title("Effective Participation Tax Rate, business income, `t'") subtitle("Income tax, payroll taxes, and welfare benefits")
	etbgraph pptr_all_i_`t', xvar("ginc_i")  mode(lpoly_scatter) title("Effective Participation Tax Rate, all income, `t'") subtitle("Income tax, payroll taxes, and welfare benefits")

	*** plots of PTR's - non-working tax only
	etbgraph pptr_tax_w_f_`t', xvar("mzda_f") mode(lpoly_scatter) title("Participation Tax Rate, non-working, full-time, `t'") subtitle("Income tax and payroll taxes")
	etbgraph pptr_tax_w_p_`t', xvar("mzda_p") mode(lpoly_scatter) title("Participation Tax Rate, non-working, part-time, `t'") subtitle("Income tax and payroll taxes")

	*** plots of PTR's - non-working ben only
	etbgraph pptr_ben_w_f_`t', xvar("mzda_f") mode(lpoly_scatter) title("Benefit Withdrawal Rate, non-working, full-time, `t'") subtitle("Welfare benefits")
	etbgraph pptr_ben_w_p_`t', xvar("mzda_p") mode(lpoly_scatter) title("Benefit Withdrawal Rate, non-working, part-time, `t'") subtitle("Welfare benefits")

	*** plots of PTR's - non-working full
	etbgraph pptr_all_w_f_`t', xvar("mzda_f") mode(lpoly_scatter) title("Effective Participation Tax Rate, non-working, full-time, `t'") subtitle("Income tax, payroll taxes, and welfare benefits")
	etbgraph pptr_all_w_p_`t', xvar("mzda_p") mode(lpoly_scatter) title("Effective Participation Tax Rate, non-working, part-time, `t'") subtitle("Income tax, payroll taxes, and welfare benefits")
	
	cd ..
	save taxbenchars_`t', replace
	
	* Other graphs not using the etbgraph command
	* Histograms of tax rate intervals
	
	* This can be done by actual histograms from indiv data or by switching to the int_dataset
	* Switch to dataset- conditions are pre-defined etc.
	* Merge graphs to have it in one place
	use wintervals_`t', clear
	
	cd plots_`t' 
	* Histograms of ATR's - individual
	twoway bar shrn_ATR_w_`t' int_taxrate, xlabel(-50(10)100, valuelabel angle(65)) title("work income") name(gw, replace) nodraw
	twoway bar shrn_ATR_b_`t' int_taxrate, xlabel(-50(10)100, valuelabel angle(65)) title("business income") name(gb, replace) nodraw
	twoway bar shrn_ATR_i_`t' int_taxrate, xlabel(-50(10)100, valuelabel angle(65)) title("all income") name(gi, replace) nodraw
	graph combine gw gb gi, ycommon xcommon title("Histogram of ATRs, t=`t'") saving(int_ATR_`t', replace) nodraw
	
	* Histograms of MTR's - individual, tax only
	twoway bar shrn_mtr_tax_w_`t' int_taxrate, xlabel(-50(10)100, valuelabel angle(65)) title("work income") name(gw, replace) nodraw
	twoway bar shrn_mtr_tax_b_`t' int_taxrate, xlabel(-50(10)100, valuelabel angle(65)) title("business income") name(gb, replace) nodraw
	twoway bar shrn_mtr_tax_i_`t' int_taxrate, xlabel(-50(10)100, valuelabel angle(65)) title("all income") name(gi, replace) nodraw
	graph combine gw gb gi, ycommon xcommon title("Histogram of MTRs (tax only), t=`t'") saving(int_mtr_tax_`t', replace) nodraw
	
	* Histograms of MTRs - individual, tax + benefit withdrawals
	twoway bar shrn_mtr_all_w_`t' int_taxrate, xlabel(-50(10)100, valuelabel angle(65)) title("work income") name(gw, replace) nodraw
	twoway bar shrn_mtr_all_b_`t' int_taxrate, xlabel(-50(10)100, valuelabel angle(65)) title("business income") name(gb, replace) nodraw
	twoway bar shrn_mtr_all_i_`t' int_taxrate, xlabel(-50(10)100, valuelabel angle(65)) title("all income") name(gi, replace) nodraw
	graph combine gw gb gi, ycommon xcommon title("Histogram of full MTRs, t=`t'") saving(int_mtr_all_`t', replace) nodraw
	
	* Histogram of PTRs - working people, tax + benefit withdrawals
	twoway bar shrn_ptr_all_w_`t' int_taxrate, xlabel(-50(10)100, valuelabel angle(65)) title("work income") name(gw, replace) nodraw
	twoway bar shrn_ptr_all_b_`t' int_taxrate, xlabel(-50(10)100, valuelabel angle(65)) title("business income") name(gb, replace) nodraw
	twoway bar shrn_ptr_all_i_`t' int_taxrate, xlabel(-50(10)100, valuelabel angle(65)) title("all income") name(gi, replace) nodraw
	graph combine gw gb gi, ycommon xcommon title("Histogram of full PTRs, currently working, t=`t'") saving(int_ptr_all_`t', replace) nodraw
	
	* Histogram of PTRs - non-working people, tax+benefit withdrawals, separate by full-time and part-time
	twoway bar shrn_ptr_all_w_f_`t' int_taxrate, xlabel(-50(10)100, valuelabel angle(65)) title("if full-time work") name(gf, replace) nodraw
	twoway bar shrn_ptr_all_w_p_`t' int_taxrate, xlabel(-50(10)100, valuelabel angle(65)) title("if part-time work") name(gp, replace) nodraw
	graph combine gf gp, ycommon xcommon title("Histogram of full PTRs, currently non-working, t=`t'") saving(int_ptr_all_nonworking_`t', replace) nodraw

	* !! Could do the same graphs with income weights
	cd ..
	use taxbenchars_`t', clear
	cd ..
end //end program taxbenplots

exit
	
//Calling taxbendiag. First, define variables which we want to compare with regime c
//local variables "inctax payrolltax payrolltaxw payrolltaxb totaltax" - if use totaltax, need to run taxbenshow 0, taxbenshow c first

local variables "inctax payrolltax payrolltaxw payrolltaxb"

//(calling the program multiple times may overwrite figures or log file)
taxbendiag `variables' if osob > 0 ,t(z) mode(abs) base(c)
taxbendiag `variables' if osob > 0 ,t(z) mode(per) base(c) ybound(300)
taxbendiag `variables' if osob > 0 ,t(z) mode(abs) base(c)
taxbendiag `variables' if osob > 0 ,t(z) mode(per) base(c) ybound(300)

exit

